# Surveys
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/surveys#overview)
  * [Detailed Guides](https://help.sap.com/docs/leanix/ea/surveys#detailed-guides)


SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.
